==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/tr.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'tr', {
	acccessKey: 'Erişim Tuşu',
	advanced: 'Gelişmiş',
	advisoryContentType: 'Danışma İçerik Türü',
	advisoryTitle: 'Danışma Başlığı',
	anchor: {
		toolbar: 'Bağlantı Ekle/Düzenle',
		menu: 'Bağlantı Özellikleri',
		title: 'Bağlantı Özellikleri',
		name: 'Bağlantı Adı',
		errorName: 'Lütfen bağlantı için ad giriniz',
		remove: 'Bağlantıyı Kaldır'
	},
	anchorId: 'Eleman Kimlik Numarası ile',
	anchorName: 'Bağlantı Adı ile',
	charset: 'Bağlı Kaynak Karakter Gurubu',
	cssClasses: 'Biçem Sayfası Sınıfları',
	emailAddress: 'E-Posta Adresi',
	emailBody: 'İleti Gövdesi',
	emailSubject: 'İleti Konusu',
	id: 'Id',
	info: 'Link Bilgisi',
	langCode: 'Dil Yönü',
	langDir: 'Dil Yönü',
	langDirLTR: 'Soldan Sağa (LTR)',
	langDirRTL: 'Sağdan Sola (RTL)',
	menu: 'Link Düzenle',
	name: 'Ad',
	noAnchors: '(Bu belgede hiç çapa yok)',
	noEmail: 'Lütfen E-posta adresini yazın',
	noUrl: 'Lütfen Link URL\'sini yazın',
	other: '<diğer>',
	popupDependent: 'Bağımlı (Netscape)',
	popupFeatures: 'Yeni Açılan Pencere Özellikleri',
	popupFullScreen: 'Tam Ekran (IE)',
	popupLeft: 'Sola Göre Konum',
	popupLocationBar: 'Yer Çubuğu',
	popupMenuBar: 'Menü Çubuğu',
	popupResizable: 'Resizable',
	popupScrollBars: 'Kaydırma Çubukları',
	popupStatusBar: 'Durum Çubuğu',
	popupToolbar: 'Araç Çubuğu',
	popupTop: 'Yukarıya Göre Konum',
	rel: 'İlişki',
	selectAnchor: 'Bağlantı Seç',
	styles: 'Biçem',
	tabIndex: 'Sekme İndeksi',
	target: 'Hedef',
	targetFrame: '<çerçeve>',
	targetFrameName: 'Hedef Çerçeve Adı',
	targetPopup: '<yeni açılan pencere>',
	targetPopupName: 'Yeni Açılan Pencere Adı',
	title: 'Link',
	toAnchor: 'Bu sayfada çapa',
	toEmail: 'E-Posta',
	toUrl: 'URL',
	toolbar: 'Link Ekle/Düzenle',
	type: 'Link Türü',
	unlink: 'Köprü Kaldır',
	upload: 'Karşıya Yükle'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/tr.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'tr', {
	acccessKey: 'Erişim Tuşu',
	advanced: 'Gelişmiş',
	advisoryContentType: 'Danışma İçerik Türü',
	advisoryTitle: 'Danışma Başlığı',
	anchor: {
		toolbar: 'Bağlantı Ekle/Düzenle',
		menu: 'Bağlantı Özellikleri',
		title: 'Bağlantı Özellikleri',
		name: 'Bağlantı Adı',
		errorName: 'Lütfen bağlantı için ad giriniz',
		remove: 'Bağlantıyı Kaldır'
	},
	anchorId: 'Eleman Kimlik Numarası ile',
	anchorName: 'Bağlantı Adı ile',
	charset: 'Bağlı Kaynak Karakter Gurubu',
	cssClasses: 'Biçem Sayfası Sınıfları',
	download: 'İndirmeye Zorla',
	displayText: 'Gösterim Metni',
	emailAddress: 'E-Posta Adresi',
	emailBody: 'İleti Gövdesi',
	emailSubject: 'İleti Konusu',
	id: 'Id',
	info: 'Link Bilgisi',
	langCode: 'Dil Yönü',
	langDir: 'Dil Yönü',
	langDirLTR: 'Soldan Sağa (LTR)',
	langDirRTL: 'Sağdan Sola (RTL)',
	menu: 'Link Düzenle',
	name: 'Ad',
	noAnchors: '(Bu belgede hiç çapa yok)',
	noEmail: 'Lütfen E-posta adresini yazın',
	noUrl: 'Lütfen Link URL\'sini yazın',
	noTel: 'Please type the phone number', // MISSING
	other: '<diğer>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Bağımlı (Netscape)',
	popupFeatures: 'Yeni Açılan Pencere Özellikleri',
	popupFullScreen: 'Tam Ekran (IE)',
	popupLeft: 'Sola Göre Konum',
	popupLocationBar: 'Yer Çubuğu',
	popupMenuBar: 'Menü Çubuğu',
	popupResizable: 'Resizable',
	popupScrollBars: 'Kaydırma Çubukları',
	popupStatusBar: 'Durum Çubuğu',
	popupToolbar: 'Araç Çubuğu',
	popupTop: 'Yukarıya Göre Konum',
	rel: 'İlişki',
	selectAnchor: 'Bağlantı Seç',
	styles: 'Biçem',
	tabIndex: 'Sekme İndeksi',
	target: 'Hedef',
	targetFrame: '<çerçeve>',
	targetFrameName: 'Hedef Çerçeve Adı',
	targetPopup: '<yeni açılan pencere>',
	targetPopupName: 'Yeni Açılan Pencere Adı',
	title: 'Link',
	toAnchor: 'Bu sayfada çapa',
	toEmail: 'E-Posta',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Link Ekle/Düzenle',
	type: 'Link Türü',
	unlink: 'Köprü Kaldır',
	upload: 'Karşıya Yükle'
} );
